==> applicationinsights-web-1.0.4-sources.jar: com/microsoft/applicationinsights/web/internal/ThreadContext.java <==
/*
 * ApplicationInsights-Java
 * Copyright (c) Microsoft Corporation
 * All rights reserved.
 *
 * MIT License
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the ""Software""), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 * THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.microsoft.applicationinsights.web.internal;

/**
 * Created by yonisha on 2/16/2015.
 */
public class ThreadContext {
    private static final InheritableThreadLocal<RequestTelemetryContext> threadLocal = new InheritableThreadLocal<RequestTelemetryContext>();

    public static void setRequestTelemetryContext(RequestTelemetryContext telemetryContext) {
        threadLocal.set(telemetryContext);
    }

    public static RequestTelemetryContext getRequestTelemetryContext() {
        return threadLocal.get();
    }

    public static void remove() {
        threadLocal.remove();
    }
}

==> applicationinsights-web-2.6.1-sources.jar: com/microsoft/applicationinsights/web/internal/ThreadContext.java <==
/*
 * ApplicationInsights-Java
 * Copyright (c) Microsoft Corporation
 * All rights reserved.
 *
 * MIT License
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the ""Software""), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit
 * persons to whom the Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 * THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.microsoft.applicationinsights.web.internal;

/**
 * Created by yonisha on 2/16/2015.
 */
public class ThreadContext {

    // No object creation allowed for this class.
    private ThreadContext() {}

    private static final InheritableThreadLocal<RequestTelemetryContext> threadLocal = new InheritableThreadLocal<>();

    /**
     * Set the context in ThreadLocal
     * @param telemetryContext
     */
    public static void setRequestTelemetryContext(RequestTelemetryContext telemetryContext) {
        threadLocal.set(telemetryContext);
    }

    /**
     * Get the context from ThreadLocal
     * @return
     */
    public static RequestTelemetryContext getRequestTelemetryContext() {
        return threadLocal.get();
    }

    /**
     * Remove the context from ThreadLocal
     */
    public static void remove() {
        threadLocal.remove();
    }
}
